@@ -1,6 +1,4 @@
-"""
-Example invalid workflow
-"""
+"""Example invalid workflow."""
 from dkist_processing_core import Workflow
 from dkist_processing_core.tests.task_example import Task
 from dkist_processing_core.tests.task_example import Task2
