@@ -1,6 +1,4 @@
-"""
-Tests of the _node.py module
-"""
+"""Tests of the _node.py module."""
 import subprocess
 from subprocess import CalledProcessError
 
@@ -14,9 +12,9 @@ from dkist_processing_core.tests.task_example import Task
 
 def test_nodes(node, fake_producer_factory):
     """
-    Given: Workflow tasks to initialize a Node
-    When: Initializing the Node with valid task and upstreams
-    Then: Node properties are created as expected
+    Given: Workflow tasks to initialize a Node.
+    When: Initializing the Node with valid task and upstreams.
+    Then: Node properties are created as expected.
     """
     node, task, upstream, name, version = node
     operator = node.operator
@@ -35,9 +33,9 @@ def test_nodes(node, fake_producer_factory):
 
 def test_node_bash_template_return_0(node):
     """
-    Given: A valid node instance
-    When: Running the bash script template WITHOUT an error producing python call
-    Then: It returns a 0
+    Given: A valid node instance.
+    When: Running the bash script template WITHOUT an error producing python call.
+    Then: It returns a 0.
     """
     node, _, _, _, _ = node
     cmd = 'python -c "pass"'
@@ -47,9 +45,9 @@ def test_node_bash_template_return_0(node):
 
 def test_node_bash_template_return_1(node):
     """
-    Given: A valid node instance
-    When: Running the bash script template WITH an error producing python call
-    Then: It returns a 1
+    Given: A valid node instance.
+    When: Running the bash script template WITH an error producing python call.
+    Then: It returns a 1.
     """
     node, _, _, _, _ = node
     cmd = 'python -c "raise Exception"'
@@ -59,9 +57,9 @@ def test_node_bash_template_return_1(node):
 
 def test_node_python():
     """
-    Given: Python jinja rendered with dag run data from a node instance
-    When: parsing the python call
-    Then: no exceptions raised
+    Given: Python jinja rendered with dag run data from a node instance.
+    When: parsing the python call.
+    Then: no exceptions raised.
     """
     # Given
     node = Node(
@@ -87,9 +85,9 @@ def test_node_python():
 
 def test_invalid_node(task_subclass):
     """
-    Given: An invalid task (not inheriting from TaskBase)
-    When: Create a Node with that Task
-    Then: Get a TypeError
+    Given: An invalid task (not inheriting from TaskBase).
+    When: Create a Node with that Task.
+    Then: Get a TypeError.
     """
 
     class GoodTask(task_subclass):
