@@ -1,4 +1,5 @@
 """Tests for the Workflow abstraction."""
+import json
 from typing import Callable
 
 import pytest
@@ -11,7 +12,7 @@ def test_workflow_metadata(workflow):
     When: accessing attributes.
     Then: Tha values are properly assigned.
     """
-    workflow_instance, category, name, version = workflow
+    workflow_instance, category, name, version, tags = workflow
 
     assert workflow_instance.workflow_name == f"{category}_{name}"
     assert workflow_instance.workflow_version == version
@@ -21,7 +22,7 @@ def test_workflow_metadata(workflow):
     assert workflow_instance._dag.dag_id == f"{category}_{name}_{version}"
     assert workflow_instance.process_category == category
     assert workflow_instance.process_name == name
-    assert workflow_instance._dag_tags == f'["{category}", "{name}", "{version}"]'
+    assert sorted(json.loads(workflow_instance._dag_tags)) == sorted([tag for tag in tags])
 
 
 def test_workflow_add_node(workflow_tasks, workflow):
@@ -31,7 +32,7 @@ def test_workflow_add_node(workflow_tasks, workflow):
       structure of A >> [B, C] >> D.
     Then: the dag object owned by the workflow has the right structure.
     """
-    workflow_instance, category, name, version = workflow
+    workflow_instance, category, name, version, _ = workflow
     TaskA, TaskB, TaskC, TaskD = workflow_tasks
     task_definitions = {
         TaskA: None,  # none
@@ -70,7 +71,7 @@ def test_invalid_workflow_add_node(workflow):
     When: Adding the task to the workflow.
     Then: Get a TypeError.
     """
-    workflow_instance, _, _, _ = workflow
+    workflow_instance, _, _, _, _ = workflow
 
     class Task:
         pass
@@ -92,7 +93,7 @@ def test_tag_db_dunder(workflow, func: Callable, attr):
     When: retrieving dunder method that should be implemented.
     Then: It is implemented.
     """
-    workflow_instance, _, _, _ = workflow
+    workflow_instance, _, _, _, _ = workflow
 
     assert getattr(workflow_instance, attr, None)
     assert func(workflow_instance)
